@@ -25,19 +25,17 @@
 
 from typing import Optional, Union
 
-from mkm.crypto.cryptography import key_algorithm
 from mkm.crypto import utf8_encode
-from mkm.crypto import AsymmetricKey, SignKey, VerifyKey
-from mkm.crypto import PublicKey, PublicKeyFactory
-from mkm.crypto import PrivateKey, PrivateKeyFactory
-from mkm.crypto import SymmetricKey, SymmetricKeyFactory
-from mkm.protocol import meta_type
-from mkm.core.profile import document_identifier
+from mkm.crypto import SymmetricKey, AsymmetricKey
+from mkm.crypto import SignKey, VerifyKey
+from mkm.crypto import PublicKey, PrivateKey
+from mkm.crypto import SymmetricKeyFactory, PublicKeyFactory, PrivateKeyFactory
+from mkm.factory import FactoryManager
 
-from mkm import ID, ANYWHERE, EVERYWHERE, Address, BaseAddressFactory
+from mkm import ANYWHERE, EVERYWHERE, Address
 from mkm import MetaType, Meta, MetaFactory
-from mkm import Document, DocumentFactory
-from mkm import BaseDocument, BaseVisa, BaseBulletin
+
+from dimp import BaseAddressFactory
 
 from .rsa import RSAPublicKey, RSAPrivateKey
 from .ecc import ECCPublicKey, ECCPrivateKey
@@ -48,60 +46,69 @@ from .eth import ETHAddress
 from .meta import DefaultMeta, BTCMeta, ETHMeta
 
 
-class GeneralPublicFactory(PublicKeyFactory):
+class RSAPublicKeyFactory(PublicKeyFactory):
 
     # Override
     def parse_public_key(self, key: dict) -> Optional[PublicKey]:
-        algorithm = key_algorithm(key=key)
-        if algorithm == AsymmetricKey.RSA:
-            return RSAPublicKey(key=key)
-        if algorithm == AsymmetricKey.ECC:
-            return ECCPublicKey(key=key)
+        return RSAPublicKey(key=key)
 
 
-class GeneralPrivateFactory(PrivateKeyFactory):
+class ECCPublicKeyFactory(PublicKeyFactory):
 
-    def __init__(self, algorithm: str):
-        super().__init__()
-        self.__algorithm = algorithm
+    # Override
+    def parse_public_key(self, key: dict) -> Optional[PublicKey]:
+        return ECCPublicKey(key=key)
+
+
+class RSAPrivateKeyFactory(PrivateKeyFactory):
 
     # Override
     def generate_private_key(self) -> Optional[PrivateKey]:
-        if self.__algorithm == AsymmetricKey.RSA:
-            return RSAPrivateKey()
-        if self.__algorithm == AsymmetricKey.ECC:
-            return ECCPrivateKey()
+        key = {'algorithm': AsymmetricKey.RSA}
+        return RSAPrivateKey(key=key)
 
     # Override
     def parse_private_key(self, key: dict) -> Optional[PrivateKey]:
-        algorithm = key_algorithm(key=key)
-        if algorithm == AsymmetricKey.RSA:
-            return RSAPrivateKey(key=key)
-        if algorithm == AsymmetricKey.ECC:
-            return ECCPrivateKey(key=key)
+        return RSAPrivateKey(key=key)
 
 
-class GeneralSymmetricFactory(SymmetricKeyFactory):
+class ECCPrivateKeyFactory(PrivateKeyFactory):
 
-    def __init__(self, algorithm: str):
+    # Override
+    def generate_private_key(self) -> Optional[PrivateKey]:
+        key = {'algorithm': AsymmetricKey.ECC}
+        return ECCPrivateKey(key=key)
+
+    # Override
+    def parse_private_key(self, key: dict) -> Optional[PrivateKey]:
+        return ECCPrivateKey(key=key)
+
+
+class AESKeyFactory(SymmetricKeyFactory):
+
+    # Override
+    def generate_symmetric_key(self) -> Optional[SymmetricKey]:
+        key = {'algorithm': SymmetricKey.AES}
+        return AESKey(key=key)
+
+    # Override
+    def parse_symmetric_key(self, key: dict) -> Optional[SymmetricKey]:
+        return AESKey(key=key)
+
+
+class PlainKeyFactory(SymmetricKeyFactory):
+
+    def __init__(self):
         super().__init__()
-        self.__algorithm = algorithm
         self.__plain_key = PlainKey()
 
     # Override
     def generate_symmetric_key(self) -> Optional[SymmetricKey]:
-        if self.__algorithm == SymmetricKey.AES:
-            return AESKey()
-        if self.__algorithm == PlainKey.PLAIN:
-            return self.__plain_key
+        return self.__plain_key
 
     # Override
     def parse_symmetric_key(self, key: dict) -> Optional[SymmetricKey]:
-        algorithm = key_algorithm(key=key)
-        if algorithm == SymmetricKey.AES:
-            return AESKey(key=key)
-        if algorithm == PlainKey.PLAIN:
-            return self.__plain_key
+        return self.__plain_key
 
 
 class GeneralAddressFactory(BaseAddressFactory):
@@ -137,61 +144,35 @@ class GeneralMetaFactory(MetaFactory):
     # Override
     def create_meta(self, key: VerifyKey, seed: Optional[str], fingerprint: Optional[bytes]) -> Meta:
         if self.__type == MetaType.MKM:
+            # MKM
             return DefaultMeta(version=self.__type, key=key, seed=seed, fingerprint=fingerprint)
-        if self.__type in [MetaType.BTC, MetaType.ExBTC]:
+        elif self.__type == MetaType.BTC:
+            # BTC
+            return BTCMeta(version=self.__type, key=key)
+        elif self.__type == MetaType.ExBTC:
+            # ExBTC
             return BTCMeta(version=self.__type, key=key, seed=seed, fingerprint=fingerprint)
-        if self.__type in [MetaType.ETH, MetaType.ExETH]:
+        elif self.__type == MetaType.ETH:
+            # ETH
+            return ETHMeta(version=self.__type, key=key)
+        elif self.__type == MetaType.ExETH:
+            # ExETH
             return ETHMeta(version=self.__type, key=key, seed=seed, fingerprint=fingerprint)
 
     # Override
     def parse_meta(self, meta: dict) -> Optional[Meta]:
-        version = meta_type(meta=meta)
+        gf = FactoryManager.general_factory
+        version = gf.get_meta_type(meta=meta)
         if version == MetaType.MKM:
+            # MKM
             out = DefaultMeta(meta=meta)
-        elif version in [MetaType.BTC, MetaType.ExBTC]:
+        elif version == MetaType.BTC or version == MetaType.ExBTC:
+            # BTC, ExBTC
             out = BTCMeta(meta=meta)
-        elif version in [MetaType.ETH, MetaType.ExETH]:
+        elif version == MetaType.ETH or version == MetaType.ExETH:
+            # ETH, ExETH
             out = ETHMeta(meta=meta)
         else:
             raise TypeError('unknown meta type: %d' % version)
         if Meta.check(meta=out):
             return out
-
-
-class GeneralDocumentFactory(DocumentFactory):
-
-    def __init__(self, doc_type: str):
-        super().__init__()
-        self.__type = doc_type
-
-    def get_type(self, identifier: ID) -> str:
-        if self.__type == '*':
-            if identifier.is_group:
-                return Document.BULLETIN
-            elif identifier.is_user:
-                return Document.VISA
-            else:
-                return Document.PROFILE
-        return self.__type
-
-    # Override
-    def create_document(self, identifier: ID, data: Optional[str], signature: Union[bytes, str, None]) -> Document:
-        doc_type = self.get_type(identifier=identifier)
-        if doc_type == Document.BULLETIN:
-            return BaseBulletin(identifier=identifier, data=data, signature=signature)
-        elif doc_type == Document.VISA:
-            return BaseVisa(identifier=identifier, data=data, signature=signature)
-        else:
-            return BaseDocument(doc_type=doc_type, identifier=identifier, data=data, signature=signature)
-
-    # Override
-    def parse_document(self, document: dict) -> Optional[Document]:
-        identifier = document_identifier(document=document)
-        if identifier is not None:
-            doc_type = self.get_type(identifier=identifier)
-            if doc_type == Document.BULLETIN:
-                return BaseBulletin(document=document)
-            elif doc_type == Document.VISA:
-                return BaseVisa(document=document)
-            else:
-                return BaseDocument(document=document)
