@@ -28,7 +28,8 @@ from typing import Union, Optional
 from mkm.crypto import VerifyKey
 
 from mkm import EntityType, Address
-from mkm import MetaType, BaseMeta
+from mkm import MetaType
+from dimp import BaseMeta
 
 from .btc import BTCAddress, NetworkType
 from .eth import ETHAddress
