@@ -31,8 +31,8 @@ from Crypto.Cipher import PKCS1_v1_5 as Cipher_PKCS1_v1_5
 from Crypto.Signature import PKCS1_v1_5 as Signature_PKCS1_v1_5
 
 from mkm.crypto import EncryptKey, DecryptKey
-from mkm.crypto import AsymmetricKey, PublicKey
-from mkm.crypto.cryptography import keys_match
+from mkm.crypto import PublicKey
+from mkm.crypto.factory import FactoryManager
 
 from .keys import BasePublicKey, BasePrivateKey
 
@@ -94,9 +94,7 @@ class RSAPublicKey(BasePublicKey, EncryptKey):
 class RSAPrivateKey(BasePrivateKey, DecryptKey):
     """ RSA Private Key """
 
-    def __init__(self, key: Optional[dict] = None):
-        if key is None:
-            key = {'algorithm': AsymmetricKey.RSA}
+    def __init__(self, key: dict):
         super().__init__(key=key)
         # check key data
         pem: str = key.get('data')
@@ -177,7 +175,8 @@ class RSAPrivateKey(BasePrivateKey, DecryptKey):
 
     # Override
     def match(self, key: EncryptKey) -> bool:
-        return keys_match(encrypt_key=key, decrypt_key=self)
+        gf = FactoryManager.general_factory
+        return gf.keys_match(encrypt_key=key, decrypt_key=self)
 
 
 def generate(bits: int) -> (RSA.RsaKey, bytes):
